libname stat482 "X:\MG\stat480~483\proc sql";
PROC SQL;
	select ID,
		SATM,
		SATV
	from stat482.survey;
QUIT;

ods listing close;
ods pdf file="X:\MG\stat480~483\proc sql\sat_scores.pdf";

PROC SQL;
	select ID,
		SATM,
		SATV
	from stat482.survey;
QUIT;

ods pdf close;
ods listing;

PROC SQL;
	CREATE TABLE SAT_Scores as
	select ID,
		SATM,
		SATV
	from stat482.survey;
QUIT;

PROC SQL;
CREATE TABLE traffic as
	select *
	from stat482.traffic;
QUIT;

PROC CONTENTS data=traffic ; 
RUN;

PROC CONTENTS data=stat482.traffic ;
RUN;

PROC SQL;
	select id,
		count_location,
		scan(count_location,-1,' ') as orientation,
		street,
		passing_vehicle_volume * 0.5 as weekends_traffic_volume
		from  traffic;
QUIT;

PROC SQL;
	TITLE1 "Traffic volume in Area SS";
	TITLE2 "During weekdays and weekends";
	select id, 
			Date_of_count label='Date of Count' format=mmddyy10.,
			count_location label='Location',
		street,
		passing_vehicle_volume label='Daily Volume' format=comma6.,
		passing_vehicle_volume * 0.5 as weekends_traffic_volume label='Weekends Volume' format=comma6.
	from  traffic;
QUIT;

PROC SQL ;
	select Name,
		Department,
		employee_annual_salary label='salary' format=dollar12.2,
	'next year raise:',
    case
		when employee_annual_salary=.                 then .
		when         employee_annual_salary < 85000   then 0.05
		when 85000 <= employee_annual_salary < 125000 then 0.03
		when employee_annual_salary >=125000          then 0.01
	else 0
		end as raise format=percent8.
	from stat482.salary;
QUIT;

PROC SQL outobs=20;
	select Name,
		Department,
		employee_annual_salary label='salary' format=dollar12.2,
	case department
      when  'POLICE'             then 'Yes'
      when  'FIRE'               then 'Yes'
      else  'N/A'
      end as Compensation
	from stat482.salary;
QUIT;

PROC SQL;
	select Name,
		Department,
		Employee_annual_salary 
	from stat482.salary
	where Department='POLICE' AND Position_title='SERGEANT';
QUIT;

PROC SQL;
	select Name,
		Department,
		Employee_annual_salary label='Salary' format=DOLLAR12.2
	from stat482.salary
	where  Employee_annual_salary between 65000 and 70000
		and Department='FIRE';
QUIT;

PROC SQL;
	select Name,
		Department,
		Position_title,
		Employee_annual_salary label='Salary' format=DOLLAR12.2
	from stat482.salary
	where  Name like 'R_B%';
QUIT;

PROC SQL;
	select Name,
		Department,
		Employee_annual_salary label='Salary' format=DOLLAR12.2,
		Employee_annual_salary * 0.02 as Bonus
	from stat482.salary
	where  Bonus >2000 ;
QUIT;

PROC SQL;
	select Name,
		Department,
		Employee_annual_salary label='Salary' format=DOLLAR12.2,
		Employee_annual_salary * 0.02 as Bonus format=DOLLAR10.2
	from stat482.salary
	where  CALCULATED Bonus >2000 ;
QUIT;

PROC SQL;
	select ID,
		Gender,
        GPA,
		SATM,
		SATV
	from stat482.survey
	where SATV is not null and GPA>3
	order by Gender, GPA ;
QUIT;

PROC SQL;
	select ID,
			Gender,
			GPA,
			SATM,
			SATV
	from stat482.survey
	where SATV is not null and GPA>3
	order by Gender desc, 3 ;
QUIT;

PROC SQL;
	select *
	from stat482.survey
	where SATV is not null and GPA>3
	order by Gender desc, MEAN(SATM,SATV) ;
QUIT;

PROC SQL;
	select avg(SATM) as average_Math,
		avg(SATV) as average_Verbal
	from stat482.survey;
QUIT ;

PROC SQL;
	select mean(SATM, SATV) as average
	from stat482.survey;
QUIT;

PROC SQL;
	select Gender,
		mean(SATM) as average_Math
	from stat482.survey;
QUIT;

PROC SQL;
	select Gender,
				mean(SATM) as average_Math
	from stat482.survey
	group by Gender;
QUIT;

PROC SQL;
	select Gender,
		SmokeCigarettes,
		mean(SATM) as average_Math
	from stat482.survey
	group by 1, 2;
QUIT;

PROC SQL;
	select count(*) as No_obs,
		count(SATM) as No_Math_records,
		count(SATV) as No_Verbal_records,
		count(distinct Gender) as Gender_group
	from stat482.survey;
QUIT;

PROC SQL;
	select Department,
			avg(Employee_annual_salary) as Avg_salary format=DOLLAR12.2
	from stat482.salary
	group by Department
	having Department in ('LAW','FINANCE','FIRE')
	order by Avg_salary;
QUIT;

PROC SQL;
		select Department,
				   avg(Employee_annual_salary) as Avg_salary format=DOLLAR12.2
		from stat482.salary
		where Department in ('LAW','FINANCE','FIRE')
		group by Department
		order by Avg_salary;
QUIT;

PROC SQL;
select Department,
		avg(Employee_annual_salary) as Avg_salary format=DOLLAR12.2
    from stat482.salary
    group by Department
  	having Avg_salary > 70000
  	order by Avg_salary;
QUIT;

PROC SQL;
	select Department,
    	avg(Employee_annual_salary) as Avg_salary format=DOLLAR12.2
	from stat482.salary
	where calculated Avg_salary > 70000
	group by Department
	order by Avg_salary;
QUIT;


PROC SQL;
	select Position_Title,
		count(*) as Employees
	from stat482.salary
	where Department='POLICE'
	group by Position_Title;
QUIT;

PROC SQL;
	select Position_Title,
		count(*) as Employees
	from stat482.salary
	group by Position_Title
	having Department='POLICE';
QUIT;

PROC SQL;
	select Department,
		avg(Employee_annual_salary) as Avg_salary format=DOLLAR12.2
	from stat482.salary
	group by Department
	having Avg_salary < (select avg(Employee_annual_salary) from stat482.salary)
	order by Avg_salary;
QUIT;

PROC SQL;
	create table demo_info as
	select ID,
		Gender,
		Height,
		Weight
	from stat482.survey, stat482.survey2;
QUIT;


PROC SQL;
		create table demo_info as
		select s1.ID,
			Gender,
			Height,
			Weight
	from stat482.survey as s1, stat482.survey2 as s2;
QUIT;


PROC SQL;
	create table demo_info as
	select s1.ID,
			Gender,
			Height,
			Weight
	from stat482.survey as s1, stat482.survey2 as s2
	where s1.ID = s2.ID;
	select *
	from demo_info;
QUIT;





	
	

